Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/core/Menu
diff options
context:
space:
mode:
authorThomas Steur <thomas.steur@gmail.com>2013-10-02 06:31:06 +0400
committerThomas Steur <thomas.steur@gmail.com>2013-10-02 06:31:06 +0400
commitf185beba0491c1f72f84d71d9c69cb11d75b0a6d (patch)
treee4fa41ce7896eaf8f46b567c7aed2461131749d4 /core/Menu
parentcc422d3f666e4b4b87037499ee8b27609d1481b5 (diff)
refs #4134 renamed some more hooks and removed some not used and not needed hooks
Diffstat (limited to 'core/Menu')
-rw-r--r--core/Menu/Admin.php4
-rw-r--r--core/Menu/Main.php4
-rw-r--r--core/Menu/Top.php4
3 files changed, 6 insertions, 6 deletions
diff --git a/core/Menu/Admin.php b/core/Menu/Admin.php
index ef89c42c4f..c706d8c8b6 100644
--- a/core/Menu/Admin.php
+++ b/core/Menu/Admin.php
@@ -32,14 +32,14 @@ class Admin extends MenuAbstract
}
/**
* Triggers the AdminMenu.addMenuEntries hook and returns the menu.
*
* @return Array
*/
public function get()
{
if (!$this->menu) {
- Piwik_PostEvent('AdminMenu.addMenuEntries');
+ Piwik_PostEvent('Menu.Admin.addItems');
}
return parent::get();
}
@@ -32,14 +32,14 @@ class Admin extends MenuAbstract
}
/**
- * Triggers the AdminMenu.addMenuEntries hook and returns the menu.
+ * Triggers the Menu.Admin.addItems hook and returns the menu.
*
* @return Array
diff --git a/core/Menu/Main.php b/core/Menu/Main.php
index fbaaf55337..8732400975 100644
--- a/core/Menu/Main.php
+++ b/core/Menu/Main.php
@@ -51,7 +51,7 @@ class Main extends MenuAbstract
}
/**
* Triggers the Menu.addMenuEntries hook and returns the menu.
*
* @return Array
*/
@@ -59,7 +59,7 @@ class Main extends MenuAbstract
{
// We trigger the Event only once!
if (!$this->menu) {
- Piwik_PostEvent('Menu.addMenuEntries');
+ Piwik_PostEvent('Menu.Reporting.addItems');
}
return parent::get();
}
@@ -51,7 +51,7 @@ class Main extends MenuAbstract
}
/**
- * Triggers the Menu.addMenuEntries hook and returns the menu.
+ * Triggers the Menu.Reporting.addItems hook and returns the menu.
*
* @return Array
diff --git a/core/Menu/Top.php b/core/Menu/Top.php
index c4e70ca1bd..31c8fbb86a 100644
--- a/core/Menu/Top.php
+++ b/core/Menu/Top.php
@@ -52,14 +52,14 @@ class Top extends MenuAbstract
}
/**
* Triggers the TopMenu.addMenuEntries hook and returns the menu.
*
* @return Array
*/
public function get()
{
if (!$this->menu) {
- Piwik_PostEvent('TopMenu.addMenuEntries');
+ Piwik_PostEvent('Menu.Top.addItems');
}
return parent::get();
}
@@ -52,14 +52,14 @@ class Top extends MenuAbstract
}
/**
- * Triggers the TopMenu.addMenuEntries hook and returns the menu.
+ * Triggers the Menu.Top.addItems hook and returns the menu.
*
* @return Array